#!/bin/bash
APPNAME=deCONZ

#LD_LIBRARY_PATH=../lib
#export LD_LIBRARY_PATH

OPTIONS="--auto-connect=1 --dbg-error=1"
EXTRA_OPTIONS=${DECONZ_OPTS:-}

UPDATE_FW_SCRIPT="/var/tmp/deCONZ-update-firmware.sh"

# provide service on port 80

function finish {
	echo "shutdown deCONZ"
	echo "resetting RaspBee"
	sudo GCFFlasher -r
}

trap finish EXIT

while [ 1 ]
do
	which setcap

	if [ $? -eq "0" ]; then
		# assume getcap also exists
		caps=`getcap /usr/bin/deCONZ`

		if [[ "$caps" == *cap_net_bind_service+ep* ]]; then
			echo capabilities ok
		else
			sudo setcap cap_net_bind_service=+ep  /usr/bin/deCONZ
			echo set capability to open ports lower 1024
		fi

		OPTIONS+=" --http-port=80"
	else
		OPTIONS+=" --http-port=8080"
	fi

	$APPNAME $OPTIONS $EXTRA_OPTIONS
	RC=$?
	echo "deCONZ - exit code ${RC}"

	case "$RC" in
	40) # Download and install updates
		deCONZ-update.sh
		;;
	41) # Restart this script in a new process
		exec $@
		;;
	42) # Download and install updates (beta channel)
		deCONZ-update.sh -c beta
		;;
	43) # Restart system
		sudo reboot
		exit 0
		;;
	44) # Shutdown system
		sudo halt
		exit 0
		;;
	45) # Download and install updates (alpha channel)
		# not yet supported just do a beta channel update
		# deCONZ-update.sh -c alpha
		deCONZ-update.sh -c beta
		;;
	46) # Update firmware only
		if [ -e "$UPDATE_FW_SCRIPT" ]; then
			sh $UPDATE_FW_SCRIPT
			# cleanup
			echo "delete $UPDATE_FW_SCRIPT"
			rm $UPDATE_FW_SCRIPT
		else
			echo "$UPDATE_FW_SCRIPT not found"
		fi
		;;
	126) # Permission problem or command is not executable
		exit 1
		;;
	127) # Command not found (try to install)
		deCONZ-update.sh
		if [ $? -ne 0 ]; then
			exit 1
		fi
		;;
	130) # CTRL-C
		exit 0
		;;
	137) # SIGKILL (128 + 9)
		exit 0
		;;
	139) # SEGV (128 + 11)
		;;
	143) # SIGTERM (128 + 15)
		exit 0
		;;
	*) echo "exit code $RC not handled"
		;;
	esac
done
